==> haskell-warp-quic-0.0.0-386-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-3Vzg0pZtFubL42T7u6eqdL
key:                  warp-quic-0.0.0-3Vzg0pZtFubL42T7u6eqdL
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  821efdb09d46b8a46b42136fe5e8f215
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-3Vzg0pZtFubL42T7u6eqdL
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http3-0.0.5-499qUrZY3YwLOFPDYiy2D3
    quic-0.1.20-1heaoVK4PZPFM4XZ4jPzEl tls-2.0.6-IakNTBA0JiNDRPputM9FQX
    wai-3.2.4-LnpkwzoHUW9G2cGUC0nKUm warp-3.3.30-BXGJjdXXESkBepSPGuenDW

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-quic-0.0.0-417-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-GZ38hnOsYovLQoMl1si4Hv
key:                  warp-quic-0.0.0-GZ38hnOsYovLQoMl1si4Hv
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  9af2aa34b282b3cbebfb57abd6d38023
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-GZ38hnOsYovLQoMl1si4Hv
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http3-0.0.9-GCpXd2HmVkt9lHXxQFOoxq
    quic-0.1.24-K0NORj2SaRC8me2Q1BkbzS tls-2.0.6-I1Ld4heBgrMIPyOIwAkQZM
    wai-3.2.4-GKgviHtnWhO3KoBTtmAmpl warp-3.4.0-4WQzRXYOsvYHbiPfjmDm2s

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
